==> tuia-advert-center-api-1.5.9-20180808.124501-23-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/FinanceBalanceRecordCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.advertiser;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 14:42
 * @descript:
 * @version: 1.0
 */
public class FinanceBalanceRecordCountDto {

    private static final long serialVersionUID = 1468732344070278793L;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期初余额 --- 返货
     */
    private Long beginBack;

    /**
     * 期末总余额
     */
    private Long endTotal;

    /**
     * 期末余额 --- 返回
     */
    private Long endBack;

    /**
     *  期初余额 --- 现金
     */
    private Long beginCash;

    /**
     *  期末余额 --- 现金
     */
    private Long endCash;


    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getBeginBack() {
        return beginBack;
    }

    public void setBeginBack(Long beginBack) {
        this.beginBack = beginBack;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }

    public Long getEndBack() {
        return endBack;
    }

    public void setEndBack(Long endBack) {
        this.endBack = endBack;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getEndCash() {
        return endCash;
    }

    public void setEndCash(Long endCash) {
        this.endCash = endCash;
    }
}

==> tuia-advert-center-api-2.5.16-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/FinanceBalanceRecordCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.advertiser;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 14:42
 * @descript:
 * @version: 1.0
 */
public class FinanceBalanceRecordCountDto  implements Serializable {

    private static final long serialVersionUID = 1468732344070278793L;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期初余额 --- 返货
     */
    private Long beginBack;

    /**
     * 期末总余额
     */
    private Long endTotal;

    /**
     * 期末余额 --- 返回
     */
    private Long endBack;

    /**
     *  期初余额 --- 现金
     */
    private Long beginCash;

    /**
     *  期末余额 --- 现金
     */
    private Long endCash;


    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getBeginBack() {
        return beginBack;
    }

    public void setBeginBack(Long beginBack) {
        this.beginBack = beginBack;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }

    public Long getEndBack() {
        return endBack;
    }

    public void setEndBack(Long endBack) {
        this.endBack = endBack;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getEndCash() {
        return endCash;
    }

    public void setEndCash(Long endCash) {
        this.endCash = endCash;
    }
}
